@@ -299,6 +299,13 @@ setMethod("show", signature(object="kRp.readability"), function(object){
     show.Fucks <- TRUE
   }
 
+  if(sum(!is.na(slot(object, "Gutierrez"))) == 0){
+    show.Gutierrez <- FALSE
+  } else {
+    prt.Gutierrez.score <- round(slot(object, "Gutierrez")[["Gutierrez"]], digits=2)
+    show.Gutierrez <- TRUE
+  }
+
   if(sum(!is.na(slot(object, "Harris.Jacobson"))) == 0){
     show.Harris.Jacobson <- FALSE
   } else {
@@ -761,6 +768,11 @@ setMethod("show", signature(object="kRp.readability"), function(object){
     cat("       Grade:", prt.Fucks.grade, "\n\n")
   } else {}
 
+  if(show.Gutierrez){
+    cat("\nGuti\u00e9rrez F\u00f3rmula de Comprensibilidad\n")
+    cat("       Score:", prt.Gutierrez.score, "\n\n")
+  } else {}
+
   if(show.Harris.Jacobson){
     cat("\nHarris-Jacobson\n")
     cat("  Parameters:", prt.Harris.Jacobson.flavour, "\n")
